import unittest
from unittest.mock import Mock
import pytest

from statustools.config import Config
from statustools import cache_clear, cache_delete, cache_get, cache_update
from statustools.constants import CACHE_STATUS, ServiceUpdateStatusEnum

class WhenCachingStatus(unittest.TestCase):
    def setUp(self):
        lock = Mock()
        lock.__enter__ = Mock(return_value='foo')
        lock.__exit__ = Mock(return_value=False)

        mock = Mock()
        mock.lock.return_value = lock

        Config.REDIS_CLIENT = mock

    def test_update_cache_success(self):
        ret = cache_update("blah", "blah")
        assert ret is None

    def test_update_cache_status_invalid(self):
        with pytest.raises(TypeError):
            cache_update(CACHE_STATUS, "blah")

    def test_update_cache_status_valid(self):
        # This test will fail if an exception is raised
        cache_update(CACHE_STATUS, ServiceUpdateStatusEnum.SUCCESS)

    def test_get_cache_success(self):
        Config.REDIS_CLIENT.get.return_value = "hi"
        ret = cache_get("blah")
        assert ret is "hi"
